==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/sr.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: sr.php,v 1.3 2005/12/07 15:02:11 bigmichi1 Exp $

$charset                = 'utf-8';

$text['title']          = 'Спецификација Система ';

$text['vitals']         = 'Систем';
$text['hostname']       = 'Име домаћина';
$text['ip']             = 'ИП адреса';
$text['kversion']       = 'Верзија кернела';
$text['dversion']       = 'Дицтрибуција';
$text['uptime']         = 'Радно време';
$text['users']          = 'Број корисника';
$text['loadavg']        = 'Просечно оптерећење';

$text['hardware']       = 'Хардверске компоненте';
$text['numcpu']         = 'Процесор';
$text['cpumodel']       = 'Moдел';
$text['mhz']            = 'Брзина чипа';
$text['cache']          = 'Величина предмеморије';
$text['bogomips']       = 'Богомипс';
$text['usb']            = 'УСБ уређаји';
$text['pci']            = 'ПЦИ уређаји';
$text['ide']            = 'ИДЕ уређаји';
$text['scsi']           = 'СЦСИ уређаји';

$text['netusage']       = 'Мрежна Употреба';
$text['device']         = 'Уређај';
$text['received']       = 'Примљено';
$text['sent']           = 'Послато';
$text['errors']         = 'Грешке';

$text['connections']    = 'Успостављене конекције';

$text['memusage']       = 'Употреба меморије';
$text['phymem']         = 'Тврда memorija';
$text['swap']           = 'СВАП меморија';

$text['fs']             = 'Монтирани фајл системи';
$text['mount']          = 'Монтирани';
$text['partition']      = 'Партиција';

$text['percent']        = 'Проценти';
$text['type']           = 'Врста';
$text['free']           = 'Слободно';
$text['used']           = 'Искоришћено';
$text['size']           = 'Величина';
$text['totals']         = 'Укупно';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ezer ez';

$text['capacity']       = 'Капацитет'; 

$text['template']       = 'Tемплат';
$text['language']       = 'Језик';
$text['submit']         = 'Пошаљи';
$text['created']        = 'Креирано: ';
$text['locale']         = 'ср';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'Дани';
$text['hours']          = 'Сати';
$text['minutes']        = 'Минути';
  
$text['temperature']    = 'Температура';
$text['voltage']        = 'Напајање';
$text['fans']           = 'Вентилатори';
$text['s_value']        = 'Снага';
$text['s_min']          = 'Мин';
$text['s_max']          = 'Mах';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Аларм';
$text['s_limit']        = 'Лимит';
$text['s_label']        = 'Име';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/sr.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: sr.php,v 1.6 2006/06/05 11:48:17 bigmichi1 Exp $

$charset                = 'utf-8';

$text['title']          = 'Спецификација Система ';

$text['vitals']         = 'Систем';
$text['hostname']       = 'Име домаћина';
$text['ip']             = 'ИП адреса';
$text['kversion']       = 'Верзија кернела';
$text['dversion']       = 'Дицтрибуција';
$text['uptime']         = 'Радно време';
$text['users']          = 'Број корисника';
$text['loadavg']        = 'Просечно оптерећење';

$text['hardware']       = 'Хардверске компоненте';
$text['numcpu']         = 'Процесор';
$text['cpumodel']       = 'Moдел';
$text['cpuspeed']       = 'CPU Speed';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Величина предмеморије';
$text['bogomips']       = 'Богомипс';
$text['usb']            = 'УСБ уређаји';
$text['pci']            = 'ПЦИ уређаји';
$text['ide']            = 'ИДЕ уређаји';
$text['scsi']           = 'СЦСИ уређаји';

$text['netusage']       = 'Мрежна Употреба';
$text['device']         = 'Уређај';
$text['received']       = 'Примљено';
$text['sent']           = 'Послато';
$text['errors']         = 'Грешке';

$text['connections']    = 'Успостављене конекције';

$text['memusage']       = 'Употреба меморије';
$text['phymem']         = 'Тврда memorija';
$text['swap']           = 'СВАП меморија';

$text['fs']             = 'Монтирани фајл системи';
$text['mount']          = 'Монтирани';
$text['partition']      = 'Партиција';

$text['percent']        = 'Проценти';
$text['type']           = 'Врста';
$text['free']           = 'Слободно';
$text['used']           = 'Искоришћено';
$text['size']           = 'Величина';
$text['totals']         = 'Укупно';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ezer ez';

$text['capacity']       = 'Капацитет'; 

$text['template']       = 'Tемплат';
$text['language']       = 'Језик';
$text['submit']         = 'Пошаљи';
$text['created']        = 'Креирано: ';
$text['locale']         = 'ср';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'Дани';
$text['hours']          = 'Сати';
$text['minutes']        = 'Минути';
  
$text['temperature']    = 'Температура';
$text['voltage']        = 'Напајање';
$text['fans']           = 'Вентилатори';
$text['s_value']        = 'Снага';
$text['s_min']          = 'Мин';
$text['s_max']          = 'Mах';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Аларм';
$text['s_limit']        = 'Лимит';
$text['s_label']        = 'Име';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
